# Table of Contents

- [joule-in-sap-leanix](<./joule-in-sap-leanix.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Joule in SAP LeanIX](<./Joule-in-SAP-LeanIX.md>)
  - [Introduction](<./Joule-in-SAP-LeanIX/Introduction.md>)
  - [Capabilities](<./Joule-in-SAP-LeanIX/Capabilities.md>)
  - [Accessing Joule](<./Joule-in-SAP-LeanIX/Accessing-Joule.md>)
